# Copyright 2024, Seiko Epson Corporation
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the “Software”), to deal in
# the Software without restriction, including without limitation the rights to use,
# copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
# Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.

import logging
import sys

from logger.config import get_config
from logger.constants import ConfigKeys, Constants, ExitCode
from logger.log import init_stdout_logger
from logger.measure.controller import Controller
from logger.utils.env import get_str


def main():
    """メイン関数 for selftest"""

    LOG_LEVEL: str = str(
        get_str(ConfigKeys.LOG_LEVEL)
        if get_str(ConfigKeys.LOG_LEVEL) in Constants.LOG_LEVELS
        else Constants.LOG_LEVEL_DEFAULT
    )
    init_stdout_logger(level=LOG_LEVEL)
    logger = logging.getLogger(__name__)

    logger.info("Start self test")

    try:
        config = get_config()

        if config is None:
            logger.error("Config file has wrong value, can't start self test")
            return ExitCode.EX_NG

        controller = Controller(config=config, start_type="")

        controller.self_test()

        return ExitCode.EX_OK

    except Exception:
        logger.exception("Failed self test")
        return ExitCode.EX_NG


if __name__ == "__main__":
    code = main()
    sys.exit(code)
